Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(99)

Unified Diff: chrome/browser/bookmarks/bookmark_storage.h

Issue 1912: Renames BoomarkBarModel to BookmarkModel. (Closed) Base URL: svn://chrome-svn/chrome/trunk/src/
Patch Set: '' Created 12 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/bookmarks/bookmark_storage.h
===================================================================
--- chrome/browser/bookmarks/bookmark_storage.h (revision 1988)
+++ chrome/browser/bookmarks/bookmark_storage.h (working copy)
@@ -9,14 +9,13 @@
#include "base/task.h"
#include "chrome/browser/browser_process.h"
-class BookmarkBarModel;
+class BookmarkModel;
class Profile;
class Value;
// BookmarkStorage handles reading/write the bookmark bar model. The
// BookmarkBarModel uses the BookmarkStorage to load bookmarks from
// disk, as well as notifying the BookmarkStorage every time the model
// changes.
//
// Internally BookmarkStorage uses BookmarkCodec to do the actual read/write.
@@ -25,7 +24,7 @@
public:
// Creates a BookmarkStorage for the specified model
- BookmarkStorage(Profile* profile, BookmarkBarModel* model);
+ BookmarkStorage(Profile* profile, BookmarkModel* model);
// Loads the bookmarks into the model, notifying the model when done. If
// load_from_history is true, the bookmarks are loaded from the file written
@@ -52,7 +51,7 @@
base::Thread* backend_thread() const { return backend_thread_; }
// The model. The model is NULL once BookmarkModelDeleted has been invoked.
- BookmarkBarModel* model_;
+ BookmarkModel* model_;
// Used to delay saves.
ScopedRunnableMethodFactory<BookmarkStorage> save_factory_;
@@ -9,14 +9,13 @@
class Value;
// BookmarkStorage handles reading/write the bookmark bar model. The
-// BookmarkBarModel uses the BookmarkStorage to load bookmarks from
-// disk, as well as notifying the BookmarkStorage every time the model
-// changes.
+// BookmarkModel uses the BookmarkStorage to load bookmarks from disk, as well
+// as notifying the BookmarkStorage every time the model changes.
//
// Internally BookmarkStorage uses BookmarkCodec to do the actual read/write.

Powered by Google App Engine
This is Rietveld 408576698